
onnx.numpy_helper
=================

.. contents::
    :local:

.. currentmodule:: onnx.numpy_helper

.. autosummary::

    from_array
    from_dict
    from_list
    from_optional
    to_array
    to_dict
    to_list
    to_optional


.. _l-numpy-helper-onnx-array:

array
+++++

.. autofunction:: onnx.numpy_helper.from_array

.. autofunction:: onnx.numpy_helper.to_array

sequence
++++++++

.. autofunction:: onnx.numpy_helper.to_list

.. autofunction:: onnx.numpy_helper.from_list

dictionary
++++++++++

.. autofunction:: onnx.numpy_helper.to_dict

.. autofunction:: onnx.numpy_helper.from_dict

optional
++++++++

.. autofunction:: onnx.numpy_helper.to_optional

.. autofunction:: onnx.numpy_helper.from_optional

tools
+++++

.. autofunction:: onnx.numpy_helper.convert_endian

.. autofunction:: onnx.numpy_helper.combine_pairs_to_complex
